==> zio-aws-fms_2.13-5.17.271.1-sources.jar: zio/aws/fms/model/ThirdPartyFirewallMissingExpectedRouteTableViolation.scala <==
package zio.aws.fms.model
import zio.ZIO
import zio.aws.fms.model.primitives.{
  LengthBoundedString,
  ResourceId,
  ViolationTarget
}
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class ThirdPartyFirewallMissingExpectedRouteTableViolation(
    violationTarget: Optional[ViolationTarget] = Optional.Absent,
    vpc: Optional[ResourceId] = Optional.Absent,
    availabilityZone: Optional[LengthBoundedString] = Optional.Absent,
    currentRouteTable: Optional[ResourceId] = Optional.Absent,
    expectedRouteTable: Optional[ResourceId] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.fms.model.ThirdPartyFirewallMissingExpectedRouteTableViolation = {
    import ThirdPartyFirewallMissingExpectedRouteTableViolation.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.fms.model.ThirdPartyFirewallMissingExpectedRouteTableViolation
      .builder()
      .optionallyWith(
        violationTarget.map(value =>
          ViolationTarget.unwrap(value): java.lang.String
        )
      )(_.violationTarget)
      .optionallyWith(
        vpc.map(value => ResourceId.unwrap(value): java.lang.String)
      )(_.vpc)
      .optionallyWith(
        availabilityZone.map(value =>
          LengthBoundedString.unwrap(value): java.lang.String
        )
      )(_.availabilityZone)
      .optionallyWith(
        currentRouteTable.map(value =>
          ResourceId.unwrap(value): java.lang.String
        )
      )(_.currentRouteTable)
      .optionallyWith(
        expectedRouteTable.map(value =>
          ResourceId.unwrap(value): java.lang.String
        )
      )(_.expectedRouteTable)
      .build()
  }
  def asReadOnly
      : zio.aws.fms.model.ThirdPartyFirewallMissingExpectedRouteTableViolation.ReadOnly =
    zio.aws.fms.model.ThirdPartyFirewallMissingExpectedRouteTableViolation
      .wrap(buildAwsValue())
}
object ThirdPartyFirewallMissingExpectedRouteTableViolation {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.fms.model.ThirdPartyFirewallMissingExpectedRouteTableViolation
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.fms.model.ThirdPartyFirewallMissingExpectedRouteTableViolation =
      zio.aws.fms.model.ThirdPartyFirewallMissingExpectedRouteTableViolation(
        violationTarget.map(value => value),
        vpc.map(value => value),
        availabilityZone.map(value => value),
        currentRouteTable.map(value => value),
        expectedRouteTable.map(value => value)
      )
    def violationTarget: Optional[ViolationTarget]
    def vpc: Optional[ResourceId]
    def availabilityZone: Optional[LengthBoundedString]
    def currentRouteTable: Optional[ResourceId]
    def expectedRouteTable: Optional[ResourceId]
    def getViolationTarget: ZIO[Any, AwsError, ViolationTarget] =
      AwsError.unwrapOptionField("violationTarget", violationTarget)
    def getVpc: ZIO[Any, AwsError, ResourceId] =
      AwsError.unwrapOptionField("vpc", vpc)
    def getAvailabilityZone: ZIO[Any, AwsError, LengthBoundedString] =
      AwsError.unwrapOptionField("availabilityZone", availabilityZone)
    def getCurrentRouteTable: ZIO[Any, AwsError, ResourceId] =
      AwsError.unwrapOptionField("currentRouteTable", currentRouteTable)
    def getExpectedRouteTable: ZIO[Any, AwsError, ResourceId] =
      AwsError.unwrapOptionField("expectedRouteTable", expectedRouteTable)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.fms.model.ThirdPartyFirewallMissingExpectedRouteTableViolation
  ) extends zio.aws.fms.model.ThirdPartyFirewallMissingExpectedRouteTableViolation.ReadOnly {
    override val violationTarget: Optional[ViolationTarget] =
      zio.aws.core.internal
        .optionalFromNullable(impl.violationTarget())
        .map(value => zio.aws.fms.model.primitives.ViolationTarget(value))
    override val vpc: Optional[ResourceId] = zio.aws.core.internal
      .optionalFromNullable(impl.vpc())
      .map(value => zio.aws.fms.model.primitives.ResourceId(value))
    override val availabilityZone: Optional[LengthBoundedString] =
      zio.aws.core.internal
        .optionalFromNullable(impl.availabilityZone())
        .map(value => zio.aws.fms.model.primitives.LengthBoundedString(value))
    override val currentRouteTable: Optional[ResourceId] = zio.aws.core.internal
      .optionalFromNullable(impl.currentRouteTable())
      .map(value => zio.aws.fms.model.primitives.ResourceId(value))
    override val expectedRouteTable: Optional[ResourceId] =
      zio.aws.core.internal
        .optionalFromNullable(impl.expectedRouteTable())
        .map(value => zio.aws.fms.model.primitives.ResourceId(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.fms.model.ThirdPartyFirewallMissingExpectedRouteTableViolation
  ): zio.aws.fms.model.ThirdPartyFirewallMissingExpectedRouteTableViolation.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-fms_3-5.17.203.2-sources.jar: zio/aws/fms/model/ThirdPartyFirewallMissingExpectedRouteTableViolation.scala <==
package zio.aws.fms.model
import zio.ZIO
import zio.aws.fms.model.primitives.{
  LengthBoundedString,
  ResourceId,
  ViolationTarget
}
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class ThirdPartyFirewallMissingExpectedRouteTableViolation(
    violationTarget: Optional[ViolationTarget] = Optional.Absent,
    vpc: Optional[ResourceId] = Optional.Absent,
    availabilityZone: Optional[LengthBoundedString] = Optional.Absent,
    currentRouteTable: Optional[ResourceId] = Optional.Absent,
    expectedRouteTable: Optional[ResourceId] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.fms.model.ThirdPartyFirewallMissingExpectedRouteTableViolation = {
    import ThirdPartyFirewallMissingExpectedRouteTableViolation.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.fms.model.ThirdPartyFirewallMissingExpectedRouteTableViolation
      .builder()
      .optionallyWith(
        violationTarget.map(value =>
          ViolationTarget.unwrap(value): java.lang.String
        )
      )(_.violationTarget)
      .optionallyWith(
        vpc.map(value => ResourceId.unwrap(value): java.lang.String)
      )(_.vpc)
      .optionallyWith(
        availabilityZone.map(value =>
          LengthBoundedString.unwrap(value): java.lang.String
        )
      )(_.availabilityZone)
      .optionallyWith(
        currentRouteTable.map(value =>
          ResourceId.unwrap(value): java.lang.String
        )
      )(_.currentRouteTable)
      .optionallyWith(
        expectedRouteTable.map(value =>
          ResourceId.unwrap(value): java.lang.String
        )
      )(_.expectedRouteTable)
      .build()
  }
  def asReadOnly
      : zio.aws.fms.model.ThirdPartyFirewallMissingExpectedRouteTableViolation.ReadOnly =
    zio.aws.fms.model.ThirdPartyFirewallMissingExpectedRouteTableViolation
      .wrap(buildAwsValue())
}
object ThirdPartyFirewallMissingExpectedRouteTableViolation {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.fms.model.ThirdPartyFirewallMissingExpectedRouteTableViolation
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.fms.model.ThirdPartyFirewallMissingExpectedRouteTableViolation =
      zio.aws.fms.model.ThirdPartyFirewallMissingExpectedRouteTableViolation(
        violationTarget.map(value => value),
        vpc.map(value => value),
        availabilityZone.map(value => value),
        currentRouteTable.map(value => value),
        expectedRouteTable.map(value => value)
      )
    def violationTarget: Optional[ViolationTarget]
    def vpc: Optional[ResourceId]
    def availabilityZone: Optional[LengthBoundedString]
    def currentRouteTable: Optional[ResourceId]
    def expectedRouteTable: Optional[ResourceId]
    def getViolationTarget: ZIO[Any, AwsError, ViolationTarget] =
      AwsError.unwrapOptionField("violationTarget", violationTarget)
    def getVpc: ZIO[Any, AwsError, ResourceId] =
      AwsError.unwrapOptionField("vpc", vpc)
    def getAvailabilityZone: ZIO[Any, AwsError, LengthBoundedString] =
      AwsError.unwrapOptionField("availabilityZone", availabilityZone)
    def getCurrentRouteTable: ZIO[Any, AwsError, ResourceId] =
      AwsError.unwrapOptionField("currentRouteTable", currentRouteTable)
    def getExpectedRouteTable: ZIO[Any, AwsError, ResourceId] =
      AwsError.unwrapOptionField("expectedRouteTable", expectedRouteTable)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.fms.model.ThirdPartyFirewallMissingExpectedRouteTableViolation
  ) extends zio.aws.fms.model.ThirdPartyFirewallMissingExpectedRouteTableViolation.ReadOnly {
    override val violationTarget: Optional[ViolationTarget] =
      zio.aws.core.internal
        .optionalFromNullable(impl.violationTarget())
        .map(value => zio.aws.fms.model.primitives.ViolationTarget(value))
    override val vpc: Optional[ResourceId] = zio.aws.core.internal
      .optionalFromNullable(impl.vpc())
      .map(value => zio.aws.fms.model.primitives.ResourceId(value))
    override val availabilityZone: Optional[LengthBoundedString] =
      zio.aws.core.internal
        .optionalFromNullable(impl.availabilityZone())
        .map(value => zio.aws.fms.model.primitives.LengthBoundedString(value))
    override val currentRouteTable: Optional[ResourceId] = zio.aws.core.internal
      .optionalFromNullable(impl.currentRouteTable())
      .map(value => zio.aws.fms.model.primitives.ResourceId(value))
    override val expectedRouteTable: Optional[ResourceId] =
      zio.aws.core.internal
        .optionalFromNullable(impl.expectedRouteTable())
        .map(value => zio.aws.fms.model.primitives.ResourceId(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.fms.model.ThirdPartyFirewallMissingExpectedRouteTableViolation
  ): zio.aws.fms.model.ThirdPartyFirewallMissingExpectedRouteTableViolation.ReadOnly =
    new Wrapper(impl)
}
